var namespaces =
[
    [ "makedocstrings", "namespacemakedocstrings.html", null ],
    [ "plcallback", "namespaceplcallback.html", null ],
    [ "Plframe", "namespacePlframe.html", null ],
    [ "plplot", "namespaceplplot.html", null ],
    [ "plplotc", "namespaceplplotc.html", null ],
    [ "Swig", "namespaceSwig.html", null ],
    [ "TclSup", "namespaceTclSup.html", null ]
];